@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous BlueZ wrapper library
  *
- * Copyright (C) 2014-2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef BLUEZQT_OBEXFILETRANSFER_H
@@ -36,6 +22,8 @@ namespace BluezQt
 class PendingCall;
 
 /**
+ * @class BluezQt::ObexFileTransfer obexfiletransfer.h <BluezQt/ObexFileTransfer>
+ *
  * OBEX file transfer.
  *
  * This class represents an OBEX file transfer interface.
@@ -54,7 +42,7 @@ public:
      * @param path path of session
      * @param parent
      */
-    explicit ObexFileTransfer(const QDBusObjectPath &path, QObject *parent = Q_NULLPTR);
+    explicit ObexFileTransfer(const QDBusObjectPath &path, QObject *parent = nullptr);
 
     /**
      * Destroys an ObexFileTransfer object.
